@@ -75,4 +75,4 @@ class PyTorchProfilerTest(unittest.TestCase):
             self.assertTrue(test_op_stats.total_host_time_us >= 1)
             self.assertTrue(test_op_stats.self_host_time_us >= 1)
 
-        self.assertNotEqual(profile.trace_data, '')
+        self.assertNotEqual(profile.trace_data, b'')
