@@ -17,7 +17,7 @@ from unittest.mock import patch, Mock
 
 import graphsignal
 from graphsignal.uploader import Uploader
-from graphsignal import metrics_pb2
+from graphsignal.proto import profiles_pb2
 
 logger = logging.getLogger('graphsignal')
 
@@ -26,32 +26,34 @@ class UploaderTest(unittest.TestCase):
     def setUp(self):
         if len(logger.handlers) == 0:
             logger.addHandler(logging.StreamHandler(sys.stdout))
-        graphsignal._get_uploader().clear()
-        graphsignal.configure(api_key='k1', debug_mode=True)
+        graphsignal.configure(
+            api_key='k1',
+            workload_name='w1',
+            debug_mode=True)
+        graphsignal._agent.uploader.clear()
 
     def tearDown(self):
-        graphsignal._get_uploader().clear()
+        graphsignal._agent.uploader.clear()
         graphsignal.shutdown()
 
     @patch.object(Uploader, '_post')
     def test_flush(self, mocked_post):
-        window = metrics_pb2.PredictionWindow()
-        graphsignal._get_uploader().upload_window(window)
-        graphsignal._get_uploader().flush()
+        profile = profiles_pb2.MLProfile()
+        graphsignal._agent.uploader.upload_profile(profile)
+        graphsignal._agent.uploader.flush()
 
         mocked_post.assert_called_once()
-        self.assertEqual(len(graphsignal._get_uploader().buffer), 0)
+        self.assertEqual(len(graphsignal._agent.uploader.buffer), 0)
 
     @patch.object(Uploader, '_post',
-                  return_value=metrics_pb2.UploadResponse().SerializeToString())
+                  return_value=profiles_pb2.UploadResponse().SerializeToString())
     def test_flush_in_thread(self, mocked_post):
-        window = metrics_pb2.PredictionWindow()
-        graphsignal._get_uploader().upload_window(window)
-        graphsignal._get_uploader().flush_in_thread()
-        graphsignal.tick()
+        profile = profiles_pb2.MLProfile()
+        graphsignal._agent.uploader.upload_profile(profile)
+        graphsignal._agent.uploader.flush_in_thread()
 
         mocked_post.assert_called_once()
-        self.assertEqual(len(graphsignal._get_uploader().buffer), 0)
+        self.assertEqual(len(graphsignal._agent.uploader.buffer), 0)
 
     @patch.object(Uploader, '_post')
     def test_flush_fail(self, mocked_post):
@@ -59,33 +61,34 @@ class UploaderTest(unittest.TestCase):
             raise URLError("Ex1")
         mocked_post.side_effect = side_effect
 
-        window = metrics_pb2.PredictionWindow()
-        graphsignal._get_uploader().upload_window(window)
-        graphsignal._get_uploader().upload_window(window)
-        graphsignal._get_uploader().flush()
+        profile = profiles_pb2.MLProfile()
+        graphsignal._agent.uploader.upload_profile(profile)
+        graphsignal._agent.uploader.upload_profile(profile)
+        graphsignal._agent.uploader.flush()
 
-        self.assertEqual(len(graphsignal._get_uploader().buffer), 2)
+        self.assertEqual(len(graphsignal._agent.uploader.buffer), 2)
 
     def test_post(self):
-        graphsignal._get_uploader().collector_url = 'http://localhost:5005'
+        graphsignal._agent.uploader.profile_api_url = 'http://localhost:5005'
 
         server = TestServer(5005)
         server.set_response_data(
-            metrics_pb2.UploadResponse().SerializeToString())
+            profiles_pb2.UploadResponse().SerializeToString())
         server.start()
 
-        window = metrics_pb2.PredictionWindow()
-        window.model.deployment_name = 'd1'
-        upload_request = metrics_pb2.UploadRequest()
-        upload_request.windows.append(window)
-        upload_request.upload_ts = 123
-        graphsignal._get_uploader()._post('metrics', upload_request.SerializeToString())
+        profile = profiles_pb2.MLProfile()
+        profile.workload_name = 'p1'
+        upload_request = profiles_pb2.UploadRequest()
+        upload_request.ml_profiles.append(profile)
+        upload_request.upload_ms = 123
+        graphsignal._agent.uploader._post(
+            'profiles', upload_request.SerializeToString())
 
-        received_upload_request = metrics_pb2.UploadRequest()
+        received_upload_request = profiles_pb2.UploadRequest()
         received_upload_request.ParseFromString(server.get_request_data())
         self.assertEqual(
-            received_upload_request.windows[0].model.deployment_name, 'd1')
-        self.assertEqual(received_upload_request.upload_ts, 123)
+            received_upload_request.ml_profiles[0].workload_name, 'p1')
+        self.assertEqual(received_upload_request.upload_ms, 123)
 
         server.join()
 
